jquery.lightbox_me.js
version 2.2

Have you ever had a DOM element that you wanted lightboxed, but didn't want all the fanciness of all the lightbox-related plug-ins out there? Lightbox_me is for you.

Lightbox_me is an essential tool for the jQuery developer's toolbox. Feed it a DOM element wrapped in a jQuery object and it will lightbox it for you, no muss no fuss.

View more information at http://buckwilson.me/lightboxme



## Usage

Lightbox_me is a jQuery plugin and requires jQuery to be included in order to work.

Include both jQuery and the lightbox_me JavaScript file before calling the plugin in your JavaScript.

Invoke the lightbox by calling the plugin on a jQuery object:
$(dom).lightbox_me();



## License

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.



## Author Information

Lightbox_me was created by Buck Wilson for Jive Software.
http://buckwilson.me
http://jivesoftware.com

